pub struct StartSession { /* private fields */ }Expand description
A session being started from code. Configure, then .await.
Implementations
Sourceimpl StartSession
impl StartSession
Sourcepub fn agent(self, name: impl Into<String>) -> Self
pub fn agent(self, name: impl Into<String>) -> Self
Run on this agent instead of the default one.
Sourcepub fn deliver_to(self, target: DeliveryTarget) -> Self
pub fn deliver_to(self, target: DeliveryTarget) -> Self
Deliver every reply of this session to a channel.